bot

package
v0.0.0-...-8a4fac4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 17, 2016 License: MIT Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Bot

type Bot struct {
	// contains filtered or unexported fields
}

Bot is a ircbot object

func NewBot

func NewBot() *Bot

NewBot creates a new Bot with the default parameters

func (*Bot) AutoMessage

func (bot *Bot) AutoMessage()

AutoMessage prints a string to chat

func (*Bot) Close

func (bot *Bot) Close()

Close the connection to the chatroom

func (*Bot) Connect

func (bot *Bot) Connect()

Connect to the chatroom

func (*Bot) ConsoleInput

func (bot *Bot) ConsoleInput()

ConsoleInput allows for controll over bot actions

func (*Bot) LogIn

func (bot *Bot) LogIn(pass string)

LogIn logs into the irc service and joins a channel

func (*Bot) Message

func (bot *Bot) Message(message string)

Message sends a string to the chat channel

func (*Bot) Start

func (bot *Bot) Start()

Jump to